import { Interfaces } from '@oclif/core';
import { Duration } from '@salesforce/kit';
declare type DurationUnit = Lowercase<keyof typeof Duration.Unit>;
export interface DurationFlagConfig extends Partial<Interfaces.OptionFlag<Duration>> {
    unit: Required<DurationUnit>;
    defaultValue?: number;
    min?: number;
    max?: number;
}
/**
 * Duration flag with built-in default and min/max validation
 * You must specify a unit
 * Defaults to undefined if you don't specify a default
 *
 * @example
 * import { SfCommand, Flags } from '@salesforce/sf-plugins-core';
 * public static flags = {
 *    'wait': duration({
 *       min: 1,
 *       unit: 'minutes'
 *       defaultValue: 33,
 *       char: 'w',
 *       description: 'Wait time in minutes'
 *    }),
 * }
 */
export declare const durationFlag: (durationConfig: DurationFlagConfig) => Interfaces.OptionFlag<Duration | undefined>;
export {};
//# sourceMappingURL=duration.d.ts.map