import { Interfaces } from '@oclif/core';
export interface IdFlagConfig extends Partial<Interfaces.OptionFlag<string>> {
    /**
     * Can specify if the version must be 15 or 18 characters long.  Leave blank to allow either 15 or 18.
     */
    length?: 15 | 18;
    /**
     * If the ID belongs to a certain sobject type, specify the 3 character prefix.
     */
    startsWith?: string;
}
/**
 * Id flag with built-in validation.  Short character is `i`
 *
 * @example
 * import { SfCommand, Flags } from '@salesforce/sf-plugins-core';
 * public static flags = {
 *     // set length or prefix
 *    'flag-name': salesforceId({ length: 15, startsWith: '00D' }),
 *    // add flag properties
 *    'flag2': salesforceId({
 *        required: true,
 *        description: 'flag2 description',
 *     }),
 *    // override the character i
 *    'flag3': salesforceId({
 *        char: 'j',
 *     }),
 * }
 */
export declare const salesforceIdFlag: (inputs?: IdFlagConfig) => Interfaces.OptionFlag<string | undefined>;
//# sourceMappingURL=salesforceId.d.ts.map